@@ -1,14 +1,14 @@
+use 5.008;
+
 package Test::Data::Array;
 use strict;
 
-use base qw(Exporter);
-use vars qw(@EXPORT $VERSION);
-$VERSION = '1.23';
+use Exporter qw(import);
+our $VERSION = '1.244';
 
-
-@EXPORT = qw( array_any_ok array_none_ok array_once_ok array_multiple_ok
+our @EXPORT = qw( array_any_ok array_none_ok array_once_ok array_multiple_ok
 	array_max_ok array_min_ok array_maxstr_ok array_minstr_ok array_sum_ok
-	array_length_ok array_empty_ok 
+	array_length_ok array_empty_ok
 	array_sortedstr_ascending_ok array_sortedstr_descending_ok
 	array_sorted_ascending_ok array_sorted_descending_ok
 	);
@@ -40,14 +40,12 @@ Ok if any element of ARRAY is ITEM.
 
 =cut
 
-sub array_any_ok($\@;$)
-	{
+sub array_any_ok($\@;$) {
 	my $element = shift;
 	my $array   = shift;
 	my $name    = shift || 'Array contains item';
 
-	foreach my $try ( @$array )
-		{
+	foreach my $try ( @$array ) {
 		next unless $try eq $element;
 		$Test->ok( 1, $name );
 		return;
@@ -62,14 +60,12 @@ Ok if no element of ARRAY is ITEM.
 
 =cut
 
-sub array_none_ok($\@;$)
-	{
+sub array_none_ok($\@;$) {
 	my $element = shift;
 	my $array   = shift;
 	my $name    = shift || 'Array does not contain item';
 
-	foreach my $try ( @$array )
-		{
+	foreach my $try ( @$array ) {
 		next unless $try eq $element;
 		$Test->ok( 0, $name );
 		return;
@@ -84,8 +80,7 @@ Ok if only one element of ARRAY is ITEM.
 
 =cut
 
-sub array_once_ok($\@;$)
-	{
+sub array_once_ok($\@;$) {
 	my $element = shift;
 	my $array   = shift;
 	my $name    = shift || 'Array contains item only once';
@@ -96,7 +91,7 @@ sub array_once_ok($\@;$)
 	foreach my $item ( @$array ) { ++$seen{$item} }
 
 	$ok = 1 if( defined $seen{$element} and $seen{$element} == 1 );
-		
+
 	$Test->ok( $ok, $name );
 	}
 
@@ -106,8 +101,7 @@ Ok if more than one element of ARRAY is ITEM.
 
 =cut
 
-sub array_multiple_ok($\@;$)
-	{
+sub array_multiple_ok($\@;$) {
 	my $element = shift;
 	my $array   = shift;
 	my $name    = shift || 'Array contains item at least once';
@@ -128,8 +122,7 @@ or equal to NUMBER.
 
 =cut
 
-sub array_max_ok($\@;$)
-	{
+sub array_max_ok($\@;$) {
 	my $item   = shift;
 	my $array  = shift;
 	my $name   = shift || 'Array maximum is okay';
@@ -146,8 +139,7 @@ or equal to NUMBER.
 
 =cut
 
-sub array_min_ok($\@;$)
-	{
+sub array_min_ok($\@;$) {
 	my $item   = shift;
 	my $array  = shift;
 	my $name   = shift || 'Array minimum is okay';
@@ -164,8 +156,7 @@ or equal to MAX.
 
 =cut
 
-sub array_maxstr_ok($\@;$)
-	{
+sub array_maxstr_ok($\@;$) {
 	my $item   = shift;
 	my $array  = shift;
 	my $name   = shift || 'Array maximum string is okay';
@@ -182,8 +173,7 @@ or equal to MAX.
 
 =cut
 
-sub array_minstr_ok($\@;$)
-	{
+sub array_minstr_ok($\@;$) {
 	my $item   = shift;
 	my $array  = shift;
 	my $name   = shift || 'Array minimum string is okay';
@@ -199,8 +189,7 @@ Ok if the numerical sum of ARRAY is SUM.
 
 =cut
 
-sub array_sum_ok($\@;$)
-	{
+sub array_sum_ok($\@;$) {
 	my $sum    = shift;
 	my $array  = shift;
 	my $name   = shift || 'Array sum is correct';
@@ -216,8 +205,7 @@ Ok if the array contains no elements.
 
 =cut
 
-sub array_empty_ok(\@;$)
-	{
+sub array_empty_ok(\@;$) {
 	my $array = shift;
 	my $name  = shift || 'Array is empty';
 
@@ -231,8 +219,7 @@ Ok if the array contains LENGTH number of elements.
 
 =cut
 
-sub array_length_ok(\@$;$)
-	{
+sub array_length_ok(\@$;$) {
 	my $array  = shift;
 	my $length = shift;
 	my $name   = shift || 'Array length is correct';
@@ -247,45 +234,40 @@ to the one before.
 
 =cut
 
-sub array_sortedstr_ascending_ok(\@;$)
-	{
+sub array_sortedstr_ascending_ok(\@;$) {
 	my $array = shift;
 	my $name  = shift || 'Array is in ascending order';
-	
+
 	my $last_seen = 0;
-	
-	ELEMENT: foreach my $index ( 1 .. $#$array )
-		{
-		if( $array->[ $index ] ge $array->[ $index - 1 ] )
-			{
+
+	ELEMENT: foreach my $index ( 1 .. $#$array ) {
+		if( $array->[ $index ] ge $array->[ $index - 1 ] ) {
 			$last_seen = $index;
 			next;
 			}
 		last;
 		}
-		
-	$last_seen == $#$array ?  
-		$Test->ok( 1, $name ) 
-			: 
+
+	$last_seen == $#$array ?
+		$Test->ok( 1, $name )
+			:
 		$Test->ok( 0, $name );
 	}
-	
+
 =item array_sortedstr_descending_ok( ARRAY, [, NAME] )
 
 Ok if each succeeding element is asciibetically less than or equal to
-the one before. 
+the one before.
 
 =cut
 
-sub array_sortedstr_descending_ok(\@;$)
-	{
+sub array_sortedstr_descending_ok(\@;$) {
 	my $array = shift;
 	my $name  = shift || 'Array is in descending order';
-	
+
 	my $last_seen = 0;
-	
-	ELEMENT: foreach my $index ( 1 .. $#$array )
-		{
+
+	ELEMENT: foreach my $index ( 1 .. $#$array ) {
 		if( $array->[ $index ] le $array->[ $index - 1 ] )
 			{
 			$last_seen = $index;
@@ -293,10 +275,10 @@ sub array_sortedstr_descending_ok(\@;$)
 			}
 		last;
 		}
-		
-	$last_seen == $#$array ?  
-		$Test->ok( 1, $name ) 
-			: 
+
+	$last_seen == $#$array ?
+		$Test->ok( 1, $name )
+			:
 		$Test->ok( 0, $name );
 	}
 
@@ -307,59 +289,53 @@ to the one before.
 
 =cut
 
-sub array_sorted_ascending_ok(\@;$)
-	{
+sub array_sorted_ascending_ok(\@;$) {
 	my $array = shift;
 	my $name  = shift || 'Array is in ascending order';
-	
+
 	my $last_seen = 0;
-	
-	ELEMENT: foreach my $index ( 1 .. $#$array )
-		{
-		if( $array->[ $index ] >= $array->[ $index - 1 ] )
-			{
+
+	ELEMENT: foreach my $index ( 1 .. $#$array ) {
+		if( $array->[ $index ] >= $array->[ $index - 1 ] ) {
 			$last_seen = $index;
 			next;
 			}
 		last;
 		}
-		
-	$last_seen == $#$array ?  
-		$Test->ok( 1, $name ) 
-			: 
+
+	$last_seen == $#$array ?
+		$Test->ok( 1, $name )
+			:
 		$Test->ok( 0, $name );
 	}
-	
+
 =item array_sorted_descending_ok( ARRAY, [, NAME] )
 
 Ok if each succeeding element is numerically less than or equal to
-the one before. 
+the one before.
 
 =cut
 
-sub array_sorted_descending_ok(\@;$)
-	{
+sub array_sorted_descending_ok(\@;$) {
 	my $array = shift;
 	my $name  = shift || 'Array is in descending order';
-	
+
 	my $last_seen = 0;
-	
-	ELEMENT: foreach my $index ( 1 .. $#$array )
-		{
-		if( $array->[ $index ] <= $array->[ $index - 1 ] )
-			{
+
+	ELEMENT: foreach my $index ( 1 .. $#$array ) {
+		if( $array->[ $index ] <= $array->[ $index - 1 ] ) {
 			$last_seen = $index;
 			next;
 			}
 		last;
 		}
-		
-	$last_seen == $#$array ?  
-		$Test->ok( 1, $name ) 
-			: 
+
+	$last_seen == $#$array ?
+		$Test->ok( 1, $name )
+			:
 		$Test->ok( 0, $name );
 	}
-	
+
 =back
 
 =head1 SEE ALSO
@@ -382,10 +358,10 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2002-2012 brian d foy.  All rights reserved.
+Copyright © 2002-2022, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the terms of the Artistic License 2.0.
 
 =cut
 
